# lapa_database_helper

## about

helper to access the database layer for my personal server.

## installation

> pip install lapa_database_helper

## usage

[reference python file](./example.py)

## configs

1. lapa_database_helper\data\config.ini

## env

- python>=3.12.0

## changelog

### v0.0.5

- Configuration is now being read with the help of lapa_commons.

### v0.0.4

- change default value of ignore_filters_and_get_all to False.

### v0.0.3

- add extra parameters for ignore_filter_and_x_all.

### v0.0.2

- rename to lapa.

### v0.0.1

- initial implementation.

## Feedback is appreciated. Thank you!
